@@ -585,6 +585,8 @@ class Pushable(soya.Volume, Pusher):
     self.next_pos = Point(self, 0.0, 0.0, 0.0)
     
   def begin_round(self):
+    soya.Volume.begin_round(self)
+    
     force = self.force
     if not self.worth_playing:
       if (abs(force.x) > 0.1) or (abs(force.y) > 0.1) or (abs(force.z) > 0.1):
@@ -815,6 +817,8 @@ class TakeableVehicle(soya.Volume):
     self.changing = 0
     
   def begin_round(self):
+    soya.Volume.begin_round(self)
+    
     if not self.changing:
       for character in self.parent.characters:
         if isinstance(character, PlayerCharacter):
@@ -1172,6 +1176,8 @@ class BossLifeBar(widget.Widget):
 
 class AllowQuit(soya.CoordSyst):
   def begin_round(self):
+    soya.CoordSyst.begin_round(self)
+    
     import soya.sdlconst as soyasdlconst
     
     for event in soya.process_event():
