@@ -264,10 +264,11 @@ def MainScreen():
     menu_h_option.choices[1].value = menu_h_option.choices[1].range[globdef.FULLSCREEN]
     menu_h_option.choices[2].value = menu_h_option.choices[2].range[globdef.QUALITY]
     menu_h_option.choices[3].value = globdef.MAX_VISION
-    menu_h_option.choices[4].value = menu_h_option.choices[4].range[globdef.SOUND]
-    menu_h_option.choices[5].value = menu_h_option.choices[5].range[globdef.MUSIC]
-    menu_h_option.choices[6].value = menu_h_option.choices[6].range[globdef.ASYNC_LOAD_MUSIC]
-    menu_h_option.choices[7].value = globdef.SOUND_SYSTEM
+    #menu_h_option.choices[4].value = menu_h_option.choices[4].range[globdef.SOUND]
+    #menu_h_option.choices[5].value = menu_h_option.choices[5].range[globdef.MUSIC]
+    #menu_h_option.choices[6].value = menu_h_option.choices[6].range[globdef.ASYNC_LOAD_MUSIC]
+    #menu_h_option.choices[7].value = globdef.SOUND_SYSTEM
+    menu_h_option.choices[4].value = str(int(round(globdef.SOUND_VOLUME * 100)))
     set_current_menu(menu_h_option)
 
   def back_h_option():
@@ -277,13 +278,15 @@ def MainScreen():
     globdef.FULLSCREEN       = (menu_h_option.choices[1].value == _('on'))
     globdef.QUALITY          = menu_h_option.choices[2].range.index(menu_h_option.choices[2].value)
     globdef.MAX_VISION       = float(menu_h_option.choices[3].value)
-    globdef.SOUND            = (menu_h_option.choices[4].value == _('on'))
-    globdef.MUSIC            = (menu_h_option.choices[5].value == _('on'))
-    globdef.ASYNC_LOAD_MUSIC = (menu_h_option.choices[6].value == _('on'))
-    globdef.SOUND_SYSTEM     = menu_h_option.choices[7].value
+    #globdef.SOUND            = (menu_h_option.choices[4].value == _('on'))
+    #globdef.MUSIC            = (menu_h_option.choices[5].value == _('on'))
+    #globdef.ASYNC_LOAD_MUSIC = (menu_h_option.choices[6].value == _('on'))
+    #globdef.SOUND_SYSTEM     = menu_h_option.choices[7].value
+    globdef.SOUND_VOLUME     = int(menu_h_option.choices[4].value) / 100.0
     soya.set_quality(globdef.QUALITY)
     soya.set_video(globdef.SCREEN_WIDTH, globdef.SCREEN_HEIGHT, globdef.FULLSCREEN, 1)
-    import slune.sound; reload(slune.sound)
+    soya.set_sound_volume(globdef.SOUND_VOLUME)
+    #import slune.sound; reload(slune.sound)
     go_back()
 
   def show_p_option():
@@ -366,12 +369,13 @@ def MainScreen():
     soya.widget.Choice(_('Fullscreen'), None, None, checkbox),
     soya.widget.Choice(_('Graphic quality'), None, None, [_('Low'), _('Medium'), _('High')]),
     soya.widget.Choice(_('Max vision distance'), None, None, [0.5, 2.0], 0.1),
-    soya.widget.Choice(_('Sounds'), None, None, checkbox),
-    soya.widget.Choice(_('Music'), None, None, checkbox),
-    soya.widget.Choice(_('Async load music'), None, None, checkbox),
-    soya.widget.Choice(_('Sound system'), None, None, ["OpenAL", "SDL_mixer"]),
+    soya.widget.Choice(_('Sound volume'), None, None, ['0', '10', '20', '30', '40', '50', '60', '70', '80', '90', '100']),
+    #soya.widget.Choice(_('Sounds'), None, None, checkbox),
+    #soya.widget.Choice(_('Music'), None, None, checkbox),
+    #soya.widget.Choice(_('Async load music'), None, None, checkbox),
+    #soya.widget.Choice(_('Sound system'), None, None, ["OpenAL", "OpenAL (old)", "SDL_mixer"]),
     soya.widget.Choice(_('Back'), back_h_option)
-    ], cancel = 8)
+    ], cancel = -1)
   menu_h_option.resize_style = CHOICELIST_RESIZE_STYLE
   menu_h_option.visible = 0
 
