@@ -178,7 +178,7 @@ class MiniMap(widget.Widget):
     self.height = 200
     self.left = soya.root_widget.width - self.width - 40
     
-    flags = filter(lambda x: isinstance(x, Flag), level)
+    flags = [x for x in level if isinstance(x, Flag)]
     flags.sort(lambda f1, f2: cmp(f1.flag_id, f2.flag_id))
     min_x = min_y =  10e1000
     max_x = max_y = -10e1000
@@ -436,7 +436,7 @@ class Opponent(slune_character.NonPlayerCharacter, slune_character.Competitor):
         yield slune.controler.goto(self, self.level.flags[self.next_flag_id], turbosity = c.turbosity + 2.0 * self.life)
         
       # Check boosting
-      p = filter(lambda p: p.played, self.level.characters)
+      p = [p for p in self.level.characters if p.played]
       if p:
         if len(p) == 1: p = p[0]
         else:           p = self.random.choice(p)
